Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4668)

Unified Diff: chrome/browser/ui/views/location_bar/location_bar_view.h

Issue 4694008: Make pink's TabContentsWrapper change compile on Windows.... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 10 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/location_bar/location_bar_view.h
===================================================================
--- chrome/browser/ui/views/location_bar/location_bar_view.h (revision 66453)
+++ chrome/browser/ui/views/location_bar/location_bar_view.h (working copy)
@@ -44,6 +44,7 @@
class SelectedKeywordView;
class StarView;
class SuggestedTextView;
+class TabContentsWrapper;
class TemplateURLModel;
namespace views {
@@ -72,7 +73,7 @@
class Delegate {
public:
// Should return the current tab contents.
- virtual TabContents* GetTabContents() = 0;
+ virtual TabContentsWrapper* GetTabContentsWrapper() = 0;
// Returns the InstantController, or NULL if there isn't one.
virtual InstantController* GetInstant() = 0;
@@ -129,8 +130,8 @@
void SetProfile(Profile* profile);
Profile* profile() const { return profile_; }
- // Returns the current TabContents.
- TabContents* GetTabContents() const;
+ // Returns the current TabContentsWrapper.
+ TabContentsWrapper* GetTabContentsWrapper() const;
// Sets |preview_enabled| for the PageAction View associated with this
// |page_action|. If |preview_enabled| is true, the view will display the

Powered by Google App Engine
This is Rietveld 408576698